# OrganisationDataCSVExportRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**start_date** | **datetime** | Must be within 30 days of provided end_date Must be a date in the past | 
**start_date_time** | **datetime** | The date must match the date provided in start_date | [optional] 
**end_date** | **datetime** | Must be a date in the past Must occur on or after the provided start_date | 
**end_date_time** | **datetime** | The date must match the date provided in end_date | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

